@@ -1,5 +1,7 @@
 package URI::Fetch;
-$URI::Fetch::VERSION = '0.09_01';
+$URI::Fetch::VERSION = '0.13_01'; # TRIAL
+
+$URI::Fetch::VERSION = '0.1301';
 use 5.008_001;
 use strict;
 use warnings;
@@ -364,6 +366,10 @@ using the C<errstr> method on the class.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/URI-Fetch>
+
 =head1 LICENSE
 
 I<URI::Fetch> is free software; you may redistribute it and/or modify it
@@ -374,4 +380,27 @@ under the same terms as Perl itself.
 Except where otherwise noted, I<URI::Fetch> is Copyright 2004 Benjamin
 Trott, ben+cpan@stupidfool.org. All rights reserved.
 
+Currently maintained by Neil Bowers.
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item * Tim Appnel
+
+=item * Mario Domgoergen
+
+=item * Karen Etheridge
+
+=item * Brad Fitzpatrick
+
+=item * Jason Hall
+
+=item * Naoya Ito
+
+=item * Tatsuhiko Miyagawa
+
+=back
+
 =cut
+
